pub fn chunk_text(text: &str, config: &ChunkerConfig) -> Vec<TextChunk>Expand description
Chunks text into overlapping segments based on token count
pub fn chunk_text(text: &str, config: &ChunkerConfig) -> Vec<TextChunk>Chunks text into overlapping segments based on token count